
package edu.usc.middleware.shibboleth.idp;

import java.io.IOException;
import java.io.OutputStreamWriter;

import org.opensaml.ws.transport.InTransport;
import org.opensaml.ws.transport.OutTransport;
import org.opensaml.ws.transport.http.HTTPOutTransport;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import edu.internet2.middleware.shibboleth.common.profile.provider.AbstractRequestURIMappedProfileHandler;

/**
 * A simple profile handler that returns the string "ok" if the IdP is able to answer the request. This may be used for
 * very basic monitoring of the IdP.
 */
public class StatusProfileHandler extends AbstractRequestURIMappedProfileHandler {

    /** Class logger. */
    private final Logger log = LoggerFactory.getLogger(StatusProfileHandler.class);

    private static String STATUS_HEADER = "X-Shibboleth-StatusKey";

    private String statusKey;

    public StatusProfileHandler(String newStatusKey) {
        log.info("instantiating new USC status profile handler.");
        statusKey = newStatusKey;
    }

    /**
     * Get the status key.
     * 
     * @return the status key
     */
    public String getStatusKey() {
        return statusKey;
    }

    /**
     * Set the status key.
     * 
     * @param newStatusKey the new status key
     */
    public void setStatusKey(String newStatusKey) {
        statusKey = newStatusKey;
    }

    /** {@inheritDoc} */
    public void processRequest(InTransport in, OutTransport out) {
        try {
            if (out instanceof HTTPOutTransport) {
                HTTPOutTransport httpOut = (HTTPOutTransport) out;
                httpOut.setHeader(STATUS_HEADER, statusKey);
            }

            OutputStreamWriter writer = new OutputStreamWriter(out.getOutgoingStream());
            writer.write("ok");
            writer.flush();
        } catch (IOException e) {
            log.error("Unable to write response", e);
        }
    }
}